[][src]Struct unsized_enum::Forget

pub struct Forget<T: ?Sized>(_);

A type that guarantees not to drop the enclosed value

This is used to allow a 'move' to be executed by copying data directly in unsafe code.

Implementations

impl<T> Forget<T>[src]

pub fn new(val: T) -> Self[src]

impl<T: ?Sized> Forget<T>[src]

pub fn get_ref(&self) -> &T[src]

Get a reference to the contained value