[−][src]Struct unsized_enum::Forget
A type that guarantees not to drop the enclosed value
This is used to allow a 'move' to be executed by copying data directly in unsafe code.
Implementations
impl<T> Forget<T>[src]
impl<T: ?Sized> Forget<T>[src]